==> teoeyes-3.0.2.tar.bz2: teoeyes-3.0.2/src/teo_range.h <==
/* ********************************************************* teo_range.h *** *
 * This library is a auxiliary teo library
 *
 * Copyright (C) 2001 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                  Time-stamp: <2001-11-09 11:45:33 sugaya>
 * ************************************************************************* */
#ifndef _TEO_RANGE_H_
#define _TEO_RANGE_H_

int	TeoCheckRangeFile		(TEOFILE	*teo, 
					 int 		col,
					 int 		row);

int	TeoCheckRangeImage 		(TEOIMAGE	*teo, 
					 int		col,
					 int 		row);

void	B_TeoGetPixelRange 		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void	U_TeoGetPixelRange		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void	S_TeoGetPixelRange 		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void	F_TeoGetPixelRange		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void 	TeoGetPixelRange		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void	B_TeoGetPixelRangePlane		(TEOIMAGE	*img,
					 int		p,
					 double 	*min,
					 double 	*max);

void	U_TeoGetPixelRangePlane 	(TEOIMAGE 	*img,
					 int 		p,
					 double 	*min,
					 double 	*max);

void 	S_TeoGetPixelRangePlane 	(TEOIMAGE 	*img,
					 int 		p,
					 double 	*min,
					 double 	*max);

void	F_TeoGetPixelRangePlane 	(TEOIMAGE 	*img,
					 int 		p,
					 double 	*min,
					 double 	*max);

void 	TeoGetPixelRangePlane 		(TEOIMAGE 	*img,
					 int 		p,
					 double 	*min,
					 double 	*max);

#endif	/* _TEO_RANGE_H_ */

/* ************************************************** End of teo_range.h *** */

==> teoeyes-3.2.0.tar.bz2: teoeyes-3.2.0/src/teo_range.h <==
/* ********************************************************* teo_range.h *** *
 * $B2hAGCM$NHO0O$J$I$rD4$Y$k4X?t(B $B%X%C%@%U%!%$%k(B
 *
 * Copyright (C) 2001-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                  Time-stamp: <05/03/21 18:17:55 sugaya>
 * ************************************************************************* */
#ifndef __TEO_RANGE_H__
#define __TEO_RANGE_H__

int	TeoCheckRangeFile		(TEOFILE	*teo, 
					 int 		col,
					 int 		row);

int	TeoCheckRangeImage 		(TEOIMAGE	*teo, 
					 int		col,
					 int 		row);

void	B_TeoGetPixelRange 		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void	U_TeoGetPixelRange		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void	S_TeoGetPixelRange 		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void	F_TeoGetPixelRange		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void 	TeoGetPixelRange		(TEOIMAGE 	*img,
					 double 	*min,
					 double 	*max);

void	B_TeoGetPixelRangePlane		(TEOIMAGE	*img,
					 int		p,
					 double 	*min,
					 double 	*max);

void	U_TeoGetPixelRangePlane 	(TEOIMAGE 	*img,
					 int 		p,
					 double 	*min,
					 double 	*max);

void 	S_TeoGetPixelRangePlane 	(TEOIMAGE 	*img,
					 int 		p,
					 double 	*min,
					 double 	*max);

void	F_TeoGetPixelRangePlane 	(TEOIMAGE 	*img,
					 int 		p,
					 double 	*min,
					 double 	*max);

void 	TeoGetPixelRangePlane 		(TEOIMAGE 	*img,
					 int 		p,
					 double 	*min,
					 double 	*max);

#endif	/* __TEO_RANGE_H__ */

/* ************************************************** End of teo_range.h *** */
